==> nodegit-0.2.4.tgz: package/src/index_conflict_iterator.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/index_conflict_iterator.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitIndexConflictIterator::GitIndexConflictIterator(git_index_conflict_iterator *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitIndexConflictIterator::~GitIndexConflictIterator() {
   }

  void GitIndexConflictIterator::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(New);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("IndexConflictIterator"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("IndexConflictIterator"), _constructor_template);
  }

  NAN_METHOD(GitIndexConflictIterator::New) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitIndexConflictIterator cannot be instantiated.");
     }

    GitIndexConflictIterator* object = new GitIndexConflictIterator(static_cast<git_index_conflict_iterator *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitIndexConflictIterator::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitIndexConflictIterator::constructor_template)->NewInstance(2, argv));
  }

  git_index_conflict_iterator *GitIndexConflictIterator::GetValue() {
    return this->raw;
  }

  git_index_conflict_iterator **GitIndexConflictIterator::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitIndexConflictIterator::constructor_template;

==> nodegit-0.2.5.tgz: package/src/index_conflict_iterator.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/index_conflict_iterator.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitIndexConflictIterator::GitIndexConflictIterator(git_index_conflict_iterator *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitIndexConflictIterator::~GitIndexConflictIterator() {
   }

  void GitIndexConflictIterator::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(JSNewFunction);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("IndexConflictIterator"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("IndexConflictIterator"), _constructor_template);
  }

  NAN_METHOD(GitIndexConflictIterator::JSNewFunction) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitIndexConflictIterator cannot be instantiated.");
     }

    GitIndexConflictIterator* object = new GitIndexConflictIterator(static_cast<git_index_conflict_iterator *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitIndexConflictIterator::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitIndexConflictIterator::constructor_template)->NewInstance(2, argv));
  }

  git_index_conflict_iterator *GitIndexConflictIterator::GetValue() {
    return this->raw;
  }

  git_index_conflict_iterator **GitIndexConflictIterator::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitIndexConflictIterator::constructor_template;
